@@ -16,7 +16,7 @@ class ApiKeyAuthentication(authentication.BaseAuthentication):
         if not client_ip:
             client_ip = request.META["REMOTE_ADDR"]
 
-        auto_user = User.objects.get_or_create(username=settings.BOT_EMAIL, email=settings.BOT_EMAIL)
+        auto_user, _ = User.objects.get_or_create(username=settings.BOT_EMAIL, email=settings.BOT_EMAIL)
         if request.headers.get("x-api-key") == settings.API_KEY:
             for ALLOWED_SUBNET in ALLOWED_SUBNETS:
                 if IPAddress(client_ip) in ALLOWED_SUBNET:
