@@ -1,8 +1,12 @@
 def get_cookie_domain(request):
     if 'HTTP_HOST' in request.META:
         host = request.META['HTTP_HOST']
-        if 'stitch.fashion' in host:
+        if 'hub3d.pvh.com' in host:
+            cookie_domain = '.hub3d.pvh.com'
+        elif 'stitch.fashion' in host:
             cookie_domain = '.stitch.fashion'
+        elif 'stitch3d.com' in host:
+            cookie_domain = '.stitch3d.com'
         else:
             cookie_domain = '.stitchdesignlab.com'
         return cookie_domain
